// RetrieveURLDialog.java
// Justin Ludiwg 1999.03.01

package edu.wooster.lu99jp26.util;

import java.awt.Dialog;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.lang.String;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JTextField;
import javax.swing.KeyStroke;


public class RetrieveURLDialog extends Dialog
implements ActionListener, WindowListener
{
	RetrieveURLListener listener;
	JTextField field;
	
	public RetrieveURLDialog (RetrieveURLListener listener)
	{
		super (new Frame (), "Retrieve file with URL...", true);
		this.listener = listener;
		
		addWindowListener (this);
		setLayout (new FlowLayout ());
		
		field = new JTextField ("http://", 50);
		field.setFont (new Font ("geneva", Font.PLAIN, 9));
		field.setCaretPosition (7);
		add (field);
		field.requestFocus ();
		
		add (makeJButton ("Retrieve", '\n'));
		add (makeJButton ("Cancel"));
		
		pack ();
		show ();
	}
	
    /**
     * Invoked when an action occurs.
     */
	public void actionPerformed (ActionEvent e)
	{
		String command = e.getActionCommand ();
		
		if (command.equals ("Retrieve"))
		{
			listener.retrieveURL (field.getText ());
			dispose ();
		}
		else if (command.equals ("Cancel"))
			dispose ();
	}
	
	/**
     * Invoked when a window has been opened.
     */
    public void windowOpened (WindowEvent e) {}

    /**
     * Invoked when a window is in the process of being closed.
     * The close operation can be overridden at this point.
     */
    public void windowClosing (WindowEvent e)
    {
    	dispose ();
    }

    /**
     * Invoked when a window has been closed.
     */
    public void windowClosed (WindowEvent e) {}

    /**
     * Invoked when a window is iconified.
     */
    public void windowIconified (WindowEvent e) {}

    /**
     * Invoked when a window is de-iconified.
     */
    public void windowDeiconified (WindowEvent e) {}

    /**
     * Invoked when a window is activated.
     */
    public void windowActivated (WindowEvent e) {}

    /**
     * Invoked when a window is de-activated.
     */
    public void windowDeactivated (WindowEvent e) {}
	
	/**
	 * creates a new JButton, adds this as a listener for the action command name
	 * @param name String button title and action command
	 */
	public JButton makeJButton (String name)
	{
		return makeJButton (name, (char) 0);
	}
	
	/**
	 * creates a new JButton, adds this as a listener for the action command name
	 * @param name String button title and action command
	 * @param key char keystroke for button (ignored if <= 0)
	 */
	public JButton makeJButton (String name, char key)
	{
		JButton b = new JButton (name);
		
		b.setActionCommand (name);
		b.addActionListener (this);
		
		if (key > 0)
			b.registerKeyboardAction (this, name, KeyStroke.getKeyStroke (key), 
					JComponent.WHEN_IN_FOCUSED_WINDOW);
		
		return b;
	}
}